Re: [PATCH v2] xdiff/xprepare: improve O(n*m) performance in xdl_cleanup_records()
- From
Jeff King <peff@peff.net>
- Date
- Aug 17, 2011, 05:21 UTC
- Message-ID
- <20110817052147.GA11253@sigill.intra.peff.net>
- In-Reply-To
- <1313546037-4104-1-git-send-email-rctay89@gmail.com>
On Wed, Aug 17, 2011 at 09:53:57AM +0800, Tay Ray Chuan wrote:
Show 19 quoted lines
> > Could we have some benchmarks to let the readers get a feel of how much > > improvement this patch brings in? > > On my msysgit machine with Marat's problematic repo > (git://slonopotamus.org/git-diff): > > rctay@TEST-123 /tmp/slono > $ time git show >/dev/null > > real 0m8.538s > user 0m0.000s > sys 0m0.031s > > rctay@TEST-123 /tmp/slono > $ time /git/git show >/dev/null > > real 0m0.672s > user 0m0.031s > sys 0m0.031s
Wait, what? It was using 0 seconds of user time before, but still taking 8.5 seconds? What was it doing? Did you actually warm up your disk cache before taking these measurements?
-Peff